"""
Class that implements pyFoamPlotWatcher
"""

from PyFoam.Execution.GnuplotRunner import GnuplotWatcher

from PyFoamApplication import PyFoamApplication

class PlotWatcher(PyFoamApplication):
    def __init__(self):
        description="""
        Gets the name of a logfile which is assumed to be the output of a
        OpenFOAM-solver. Parses the logfile for information about the
        convergence of the solver and generates gnuplot-graphs. Watches the
        file until interrupted.
        """
        PyFoamApplication.__init__(self,description=description,usage="%prog [options] <logfile>",interspersed=True,nr=1)

    def addOptions(self):
        self.parser.add_option("--frequency",type="float",dest="frequency",default=1.,help="The frequency with which output should be generated (in seconds)")
        self.parser.add_option("--persist",action="store_true",dest="persist",default=True,help="Gnuplot windows stay after interrupt")
        self.parser.add_option("--non-persist",action="store_false",dest="persist",help="Gnuplot windows close after interrupt")
        self.parser.add_option("--tail",type="long",dest="tail",default=5000L,help="The length at the end of the file that should be output (in bytes)")
        self.parser.add_option("--silent",action="store_true",dest="silent",default=False,help="Logfile is not copied to the terminal")
        self.parser.add_option("--no-linear",action="store_false",default=True,dest="linear",help="Don't plot the linear solver convergence")
        self.parser.add_option("--no-continuity",action="store_false",default=True,dest="cont",help="Don't plot the continuity info")
        self.parser.add_option("--no-bound",action="store_false",default=True,dest="bound",help="Don't plot the bounding of variables")
        self.parser.add_option("--with-iterations",action="store_true",default=False,dest="iterations",help="Plot the number of iterations of the linear solver")
        self.parser.add_option("--with-courant",action="store_true",default=False,dest="courant",help="Plot the courant-numbers of the flow")
        self.parser.add_option("--with-execution",action="store_true",default=False,dest="execution",help="Plot the execution time of each time-step")
        self.parser.add_option("--with-all",action="store_true",default=False,dest="withAll",help="Switch all possible plots on")
        self.parser.add_option("--custom-regexp",action="store",default=None,dest="customRegex",help="Add a custom regular expression to be plotted")

    def run(self):
        if self.opts.withAll:
            self.opts.linear=True
            self.opts.cont=True
            self.opts.bound=True
            self.opts.iterations=True
            self.opts.courant=True
            self.opts.execution=True
    
        run=GnuplotWatcher(self.parser.getArgs()[0],smallestFreq=self.opts.frequency,persist=self.opts.persist,tailLength=self.opts.tail,silent=self.opts.silent,plotLinear=self.opts.linear,plotCont=self.opts.cont,plotBound=self.opts.bound,plotIterations=self.opts.iterations,plotCourant=self.opts.courant,plotExecution=self.opts.execution,customRegexp=self.opts.customRegex)

        run.start()
