"""
Application class that implements pyFoamUtilityRunner
"""

from PyFoamApplication import PyFoamApplication

from PyFoam.Execution.UtilityRunner import UtilityRunner
from PyFoam.Basics.FoamOptionParser import FoamOptionParser

import sys,string
from os import path

class UtilityRunnerApp(PyFoamApplication):
    def __init__(self):
        description="""
        Runs a OpenFoam Utility and analyzes the output.  Needs a regular
        expression to look for.  The next 3 arguments are the usual OpenFoam
        argumens (<solver> <directory> <case>) and passes them on (plus
        additional arguments).  Output is sent to stdout and a logfile inside
        the case directory (PyFoamUtility.logfile).  The Directory
        PyFoamUtility.analyzed contains a file test with the information of
        the regexp (the pattern groups).
        """

        PyFoamApplication.__init__(self,description=description)

    def addOptions(self):
        self.parser.add_option("-r","--regexp",type="string",dest="regexp",help="The regular expression to look for")
        self.parser.add_option("-n","--name",type="string",dest="name",default="test",help="The name for the resulting file")
        self.parser.add_option("--echo",action="store_true",dest="echo",default=False,help="Echo the result file after the run")
        self.parser.add_option("--silent",action="store_true",dest="silent",default=False,help="Don't print the output of the utility to the console")

    def run(self):
        if self.parser.getOptions().regexp==None:
            self.parser.error("Regular expression needed")
    
        run=UtilityRunner(argv=self.parser.getArgs(),silent=self.parser.getOptions().silent)

        run.add(self.parser.getOptions().name,self.parser.getOptions().regexp)

        run.start()

        fn=path.join(run.getDirname(),self.parser.getOptions().name)

        if self.parser.getOptions().echo:
            fh=open(fn)
            print fh.read()
            fh.close()
        else:
            print sys.argv[0]+": Output written to file "+fn
