"""Analyze information from the linear solver"""

import re

linearRegExp="^(.+):  Solving for (.+), Initial residual = (.+), Final residual = (.+), No Iterations (.+)$"
    
from FileLineAnalyzer import FileLineAnalyzer
from TimeLineLineAnalyzer import TimeLineLineAnalyzer

class LinearSolverLineAnalyzer(FileLineAnalyzer):
    """Parses for information about the linear solver

    Files of the form linear_<var> are written, where <var> is the
    variable for which the solver was used"""
    
    def __init__(self):
        FileLineAnalyzer.__init__(self,titles=["Initial","Final","Iterations"])
        self.exp=re.compile(linearRegExp)

    def doAnalysis(self,line):
        m=self.exp.match(line)
        if m!=None:
            solver=m.groups()[0]
            name=m.groups()[1]
            rest=m.groups()[2:]
            self.files.write("linear_"+name,self.getTime(),rest)
            
class TimeLineLinearSolverLineAnalyzer(TimeLineLineAnalyzer):
    """Parses for imformation about the linear solver and collects the residuals in timelines"""
    
    def __init__(self):
        TimeLineLineAnalyzer.__init__(self)
        self.lines.setDefault(1.)
        self.lines.setExtend(True)
        self.exp=re.compile(linearRegExp)
        
    def doAnalysis(self,line):
        m=self.exp.match(line)
        if m!=None:
            name=m.groups()[1]
            resid=m.groups()[2]
            
            self.lines.setValue(name,resid)
            
class TimeLineLinearIterationsSolverLineAnalyzer(TimeLineLineAnalyzer):
    """Parses for imformation about the linear solver and collects the residuals in timelines"""
    
    def __init__(self):
        TimeLineLineAnalyzer.__init__(self)
        self.lines.setDefault(1.)
        self.lines.setExtend(True)
        self.exp=re.compile(linearRegExp)
        
    def doAnalysis(self,line):
        m=self.exp.match(line)
        if m!=None:
            name=m.groups()[1]
            iter=m.groups()[4]
            
            self.lines.setValue(name,iter)
